import 'dart:math';

import 'package:random/models/game/game_board.dart';
import 'package:random/models/game/game_cell.dart';
import 'package:random/models/game/game_settings.dart';

class Game {
  GameBoard board;
  GameSettings settings;
  bool isRunning = false;
  bool isFinished = false;
  int availableBlocksCount = 0;
  int movesCount = 0;
  int score = 0;

  Game({
    required this.board,
    required this.settings,
    this.isRunning = false,
  });

  factory Game.createNull() {
    return Game(
      board: GameBoard.createNull(),
      settings: GameSettings.createDefault(),
    );
  }

  factory Game.createNew({GameSettings? gameSettings}) {
    GameSettings settings = gameSettings ?? GameSettings.createDefault();

    return Game(
      board: GameBoard.createRandom(settings),
      settings: settings,
      isRunning: true,
    );
  }

  void stop() {
    this.isRunning = false;
    this.isFinished = true;
  }

  GameCell getCell(int x, int y) {
    return this.board.cells[y][x];
  }

  int? getCellValue(int x, int y) {
    return this.getCell(x, y).value;
  }

  void updateCellValue(int x, int y, int? value) {
    this.board.cells[y][x].value = value;
  }

  void setRandomCellValue(int x, int y, GameSettings settings) {
    final int maxValue = settings.colorsCount;
    final rand = new Random();
    int value = 1 + rand.nextInt(maxValue);

    this.board.cells[y][x].value = value;
  }

  void increaseMovesCount() {
    this.movesCount += 1;
  }

  void increaseScore(int? count) {
    this.score += (count ?? 0);
  }

  String toString() {
    return 'Game(' + this.toJson().toString() + ')';
  }

  Map<String, dynamic>? toJson() {
    return <String, dynamic>{
      'board': this.board.toJson(),
      'settings': this.settings.toJson(),
      'isRunning': this.isRunning,
      'isFinished': this.isFinished,
      'availableBlocksCount': this.availableBlocksCount,
      'movesCount': this.movesCount,
      'score': this.score,
    };
  }

  void dump() {
    GameBoard.printGrid(this.board.cells);
    print(this.settings.toJson());
    print(this.toJson());
  }
}
