import 'dart:math';

import 'package:random/models/game/game_cell.dart';
import 'package:random/models/game/game_settings.dart';

class GameBoard {
  final List<List<GameCell>> cells;

  GameBoard({
    required this.cells,
  });

  factory GameBoard.createNull() {
    return GameBoard(cells: []);
  }

  factory GameBoard.createRandom(GameSettings gameSettings) {
    final int boardSizeHorizontal = gameSettings.boardSize;
    final int boardSizeVertical = gameSettings.boardSize;
    final int maxValue = gameSettings.colorsCount;

    final rand = new Random();

    List<List<GameCell>> grid = [];
    for (var rowIndex = 0; rowIndex < boardSizeVertical; rowIndex++) {
      List<GameCell> row = [];
      for (var colIndex = 0; colIndex < boardSizeHorizontal; colIndex++) {
        int value = 1 + rand.nextInt(maxValue);
        row.add(GameCell(value));
      }
      grid.add(row);
    }
    printGrid(grid);

    return GameBoard(cells: grid);
  }

  static printGrid(List<List<GameCell>> cells) {
    print('');
    print('-------');
    for (var rowIndex = 0; rowIndex < cells.length; rowIndex++) {
      String row = '';
      for (var colIndex = 0; colIndex < cells[rowIndex].length; colIndex++) {
        row += cells[rowIndex][colIndex].value.toString();
      }
      print(row);
    }
    print('-------');
    print('');
  }

  String toString() {
    return 'Board(' + this.toJson().toString() + ')';
  }

  Map<String, dynamic>? toJson() {
    return <String, dynamic>{
      'cells': this.cells.toString(),
    };
  }
}
