import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:unicons/unicons.dart';

import 'package:random/config/theme.dart';
import 'package:random/cubit/data_cubit.dart';
import 'package:random/cubit/settings_cubit.dart';
import 'package:random/ui/widgets/header_app.dart';

class DemoPage extends StatelessWidget {
  const DemoPage({super.key});

  @override
  Widget build(BuildContext context) {
    return Material(
      color: Theme.of(context).colorScheme.background,
      child: ListView(
        padding: const EdgeInsets.symmetric(horizontal: 4),
        physics: const BouncingScrollPhysics(),
        children: <Widget>[
          SizedBox(height: 8),
          AppHeader(text: 'TOP'),
          SizedBox(height: 20),
          persistedCounterBlock(BlocProvider.of<DataCubit>(context)),
          SizedBox(height: 20),
          testBlocConsumer(),
          testBlocBuilder(),
          SizedBox(height: 20),
          fakeApiCall(),
          SizedBox(height: 20),
          AppHeader(text: 'BOTTOM'),
        ],
      ),
    );
  }

  Widget persistedCounterBlock(DataCubit dataCubit) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.center,
      crossAxisAlignment: CrossAxisAlignment.center,
      children: [
        IconButton(
          icon: Icon(UniconsSolid.arrow_circle_down),
          color: appTheme.primaryColor,
          onPressed: () => dataCubit.updateCounter(-1),
        ),
        testBlocConsumer(),
        IconButton(
          icon: Icon(UniconsSolid.arrow_circle_up),
          color: appTheme.primaryColor,
          onPressed: () => dataCubit.updateCounter(1),
        ),
      ],
    );
  }

  Widget fakeApiCall() {
    return BlocBuilder<SettingsCubit, SettingsState>(
      builder: (context, settingsSate) {
        return Column(
          mainAxisAlignment: MainAxisAlignment.center,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            Text('apiUrl: ' + settingsSate.apiUrl.toString()),
            Text('securityToken: ' + (settingsSate.securityToken.toString())),
            Text('interfaceType: ' + settingsSate.interfaceType.toString()),
          ],
        );
      },
    );
  }

  Widget testBlocConsumer() {
    return BlocConsumer<DataCubit, DataState>(
      listener: (context, dataState) {
        // do stuff here based on state
      },
      builder: (context, dataState) {
        // return widget here based on state
        return Text('BlocConsumer / ' + dataState.toString());
      },
    );
  }

  Widget testBlocListener() {
    return BlocListener<DataCubit, DataState>(
      listener: (context, dataState) {
        // do stuff here based on state
      },
    );
  }

  Widget testBlocBuilder() {
    return BlocBuilder<DataCubit, DataState>(
      builder: (context, dataState) {
        // return widget here based on state
        return Text('BlocBuilder / ' + dataState.toString());
      },
    );
  }
}
