import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_swipe/flutter_swipe.dart';

import 'package:random/cubit/bottom_nav_cubit.dart';
import 'package:random/ui/screens/about_page.dart';
import 'package:random/ui/screens/api_page.dart';
import 'package:random/ui/screens/camera_page.dart';
import 'package:random/ui/screens/demo_page.dart';
import 'package:random/ui/screens/game_page.dart';
import 'package:random/ui/screens/graph_page.dart';
import 'package:random/ui/screens/settings_page.dart';
import 'package:random/ui/widgets/app_bar.dart';
import 'package:random/ui/widgets/bottom_nav_bar.dart';

class SkeletonScreen extends StatefulWidget {
  const SkeletonScreen({super.key});

  @override
  State<SkeletonScreen> createState() => _SkeletonScreenState();
}

class _SkeletonScreenState extends State<SkeletonScreen> {
  @override
  Widget build(BuildContext context) {
    const List<Widget> pageNavigation = <Widget>[
      DemoPage(),
      ApiPage(),
      CameraPage(),
      GraphPage(),
      GamePage(),
      SettingsPage(),
      AboutPage(),
    ];

    return Scaffold(
      extendBodyBehindAppBar: false,
      appBar: StandardAppBar(),
      body: Swiper(
        itemCount: BlocProvider.of<BottomNavCubit>(context).pagesCount,
        itemBuilder: (BuildContext context, int index) {
          return pageNavigation.elementAt(index);
        },
        pagination: SwiperPagination(
          builder: SwiperCustomPagination(
            builder: (BuildContext context, SwiperPluginConfig config) {
              return BottomNavBar(swipeController: config.controller);
            },
          ),
        ),
        onIndexChanged: (newPageIndex) {
          BlocProvider.of<BottomNavCubit>(context).updateIndex(newPageIndex);
        },
        outer: true,
        loop: false,
      ),
      backgroundColor: Theme.of(context).colorScheme.background,
    );
  }
}
